﻿SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';


DROP SCHEMA IF EXISTS `gespro` ;
CREATE SCHEMA IF NOT EXISTS `gespro` DEFAULT CHARACTER SET latin1 ;
USE `gespro` ;

-- -----------------------------------------------------
-- Table `gespro`.`Empleado`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `gespro`.`Empleado` ;

CREATE  TABLE IF NOT EXISTS `gespro`.`Empleado` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(45) NOT NULL ,
  `apellidos` VARCHAR(45) NOT NULL ,
  `administrador` TINYINT(1) NOT NULL DEFAULT false ,
  `telefono` VARCHAR(15) NULL ,
  `correo` VARCHAR(45) NULL ,
  `loginuser` VARCHAR(15) NOT NULL ,
  `pwd` VARCHAR(15) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `gespro`.`Proyecto`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `gespro`.`Proyecto` ;

CREATE  TABLE IF NOT EXISTS `gespro`.`Proyecto` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(45) NOT NULL ,
  `horaspresupuestadas` INT NOT NULL ,
  `tipo` VARCHAR(2) NOT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `gespro`.`ProyectoEmpleado`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `gespro`.`ProyectoEmpleado` ;

CREATE  TABLE IF NOT EXISTS `gespro`.`ProyectoEmpleado` (
  `empleado` INT NOT NULL ,
  `proyecto` INT NOT NULL ,
  PRIMARY KEY (`empleado`, `proyecto`) ,
  INDEX `fk_Empleados_has_Proyecto_Proyecto1` (`proyecto` ASC) ,
  INDEX `fk_Empleados_has_Proyecto_Empleados` (`empleado` ASC) ,
  CONSTRAINT `fk_Empleados_has_Proyecto_Empleados`
    FOREIGN KEY (`empleado` )
    REFERENCES `gespro`.`Empleado` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Empleados_has_Proyecto_Proyecto1`
    FOREIGN KEY (`proyecto` )
    REFERENCES `gespro`.`Proyecto` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `gespro`.`Incidencia`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `gespro`.`Incidencia` ;

CREATE  TABLE IF NOT EXISTS `gespro`.`Incidencia` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `proyecto` INT NULL ,
  `empleado` INT NOT NULL ,
  `descripcion` VARCHAR(255) NOT NULL ,
  `prioridad` VARCHAR(2) NOT NULL ,
  `dia` DATE NOT NULL ,
  `horas` INT NOT NULL ,
  `estado` VARCHAR(2) NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_Incidencia_Empleado` (`empleado` ASC) ,
  INDEX `fk_Incidencia_Proyecto` (`proyecto` ASC) ,
  CONSTRAINT `fk_Incidencia_Empleado`
    FOREIGN KEY (`empleado` )
    REFERENCES `gespro`.`Empleado` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Incidencia_Proyecto`
    FOREIGN KEY (`proyecto` )
    REFERENCES `gespro`.`Proyecto` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


DROP USER `gespro` ;
CREATE USER `gespro` IDENTIFIED BY 'gespro';
GRANT ALL PRIVILEGES ON *.* TO gespro@"%" IDENTIFIED BY 'gespro' WITH GRANT OPTION;





SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;




USE `gespro` ;

/* inserta los empleados con el loginuser i password como usuario de la uoc */
insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd) 
values ('Emilio','Verdejo Grasa',true,'935805850','everdejog@uoc.edu','everdejog','everdejog');

insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Josep Maria','Camps Riba',true,'935805850','jcampsri@uoc.edu','jcampsri','jcampsri');

insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Santi','Caballé Llobet',true,'935805850','scaballe@uoc.edu','scaballe','scaballe');

insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Daniel','Boerner', false,'935805850','dboerner@uoc.edu','dboerner','dboerner');


insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Jordi','García Casanova',false,'935805850','jordigar@uoc.edu','jordigar','jordigar');


insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Josep','Jimenez  Bautista',false,'935805850','jjimenezba@uoc.edu','jjimenezba','jjimenezba');

insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Sergio','Maeso  Garcia',false,'935805850','jsmaesog@uoc.edu','jsmaesog','jsmaesog');

insert into empleado (nombre,apellidos,administrador,telefono,correo,loginuser,pwd)
values ('Daniel','Peña  Gómez',false,'935805850','bcndaniel@uoc.edu','bcndaniel','bcndaniel');


/* inserta los proyectos */
INSERT INTO `proyecto` (`id`, `nombre`, `horaspresupuestadas`, `tipo`) VALUES (1,'Estudi dels frameworks del mercat',60,'CE'),
                                                                              (2,'Disseny del jwframework',40,'CE'),
																			  (3,'Implementació del jwframework',100,'CE'),
																			  (4,'Disseny de Aplicació GesPro',40,'FA'),
																			  (5,'Implementació de Gespro',80,'FA'),
																			  (6,'Memoria i presentació jwframework',20,'CE'),
																			  (7,'Tutorització presencial de PFC',3,'CE'),
																			  (8,'Manteniment i millores de jwframework',200,'MA'),
																			  (9,'Manteniment i millores de Gespro',400,'MA');


/* inserta los proyectos-empleado */
INSERT INTO `proyectoempleado` VALUES (1,1),(2,1),(3,1),(1,2),(2,2),(3,2),(1,3),(2,3),(3,3),
                                      (1,4),(2,4),(3,4),(1,5),(2,5),(3,5),(1,6),(2,6),(3,6),
									  (1,7),(2,7),(3,7),(4,7),(5,7),(6,7),(7,7),(8,7),(1,8),
									  (2,8),(3,8),(1,9),(2,9),(3,9);

/* inserta los incidencias */
INSERT INTO `incidencia` VALUES (1,7,1,'Reunió kickoff presentació de PFC. Estudi de opcions de projecte a desenvolupar','ME','2012-03-03',2,'CE'),
                                (2,7,7,'Presentació de PFC. Plantejament de opcions de projecte j2ee','BA','2012-03-03',2,'CE'),
								(3,7,2,'Presentació PFC: Conèixer presencialment els alumnes del curs i els plantejaments dels seus projectes','BA','2012-03-03',2,'CE'),
								(4,7,3,'Presentació PFC-J2ee','BA','2012-03-03',2,'CE'),(5,7,6,'Plantejament del framework per xarxes socials','ME','2012-03-03',2,'CE'),
								(6,1,1,'Estudi dels patrons mes utilitzats.\r\nEstudi del Model Vista Controlador','ME','2012-03-15',8,'CE'),
								(7,1,1,'Estudi de framework Apache Struts','ME','2012-03-16',30,'CE'),
								(8,1,1,'Estudi de framework JSF','ME','2012-03-23',30,'CE'),
								(9,1,1,'Estudi de framework Spring MVC','ME','2012-04-05',30,'CE'),
								(10,1,1,'Document de estudis de frameworks i lliurament de la PAC1','AT','2012-04-16',8,'CE'),
								(11,1,2,'Valoració documentació aportada en PAC1','AT','2012-04-19',8,'CE'),
								(12,2,1,'Estudi dels patrons que s\'aplicaran al framework: frontcontroller, aplicationcontroller, helper....','BA','2012-04-23',12,'CE'),
								(13,2,1,'Disseny diagrama de classes del jwframework','BA','2012-04-25',12,'CE'),
								(14,2,1,'Disseny del diagrama de seqüencies d\'inicialització del jwframework','ME','2012-04-30',12,'CE'),
								(15,2,1,'Diagrama de seqüencies de peticions sobre accions del jwframework','ME','2012-05-01',8,'CE'),
								(16,2,1,'Document pdf de disseny del jwframework','AT','2012-05-03',8,'CE'),
								(17,3,1,'Implementació del frontcontroller i el aplicacioncontroller: Classes servlet, Aplicacion i AplicacionConfigurador.','BA','2012-05-04',40,'CE'),
								(18,3,1,'Creació del tagLib per facilitar al usuari la tasca de creació de les vistes','BA','2012-05-14',20,'CE'),
								(19,3,1,'Implementació i prova de totes les jwfException produïdes al jwframework','ME','2012-05-17',5,'CE'),
								(20,3,1,'Javadoc del jwframework i joc de proves bàsic de dispatchers de vistes redirect, jsp i freemaker.','BA','2012-05-21',10,'CE'),
								(21,4,1,'Disseny del Diagrama ER-base de dades i Diagrama de classes bàsic.','ME','2012-04-25',8,'CE'),
								(22,4,1,'Disseny de Accions necesaries segons el manteniments de les taules.','BA','2012-04-27',4,'CE'),
								(23,4,1,'Disseny de pantalles del gespro','ME','2012-04-30',10,'CE'),
								(24,4,1,'Document pdf amb el disseny de l\'aplicació Gespro','AT','2012-05-02',4,'CE'),
								(25,5,1,'Creació de la base de dades gespro, usuaris i permisos','BA','2012-05-14',4,'CE'),
								(26,5,1,'Creació de Pojos hibernate i DAO de comunicació','ME','2012-05-15',4,'CE'),
								(27,5,1,'Creació d\'accions necesaries i capa de servei de empleats','BA','2012-05-17',8,'CE'),
								(28,5,1,'Implementació de accions i capa de servei de projectes','ME','2012-05-18',8,'CE'),
								(29,5,1,'Implementació d\'accions i capa de servei de Incidencies','AT','2012-05-21',8,'CE'),
								(30,5,1,'Implementació de interceptors i login d\'usuari a l\'aplicació gespro','AT','2012-05-22',8,'CE'),
								(31,5,1,'Creació de joc de proves i funcionament correcte de l\'aplicació gespro','AT','2012-05-24',2,'AB'),
								(32,5,1,'Joc de proves i validació del correcte funcionament de Gespro','AT','2012-05-24',10,'AB'),
								(33,3,2,'Validació del lliurament del producte jwframework','AT','2012-06-04',10,'AB'),
								(34,5,2,'Valoració del lliurable programari prova del jwframework: Gestió de projectes (Gespro)','AT','2012-06-04',10,'AB'),
								(35,6,1,'Crear document únic dels lliurables de les tres pacs i cumplimentar index, dedicatoria, figures....','AT','2012-05-30',8,'AB'),
								(36,6,1,'Elaborar presentació final de PFC','AT','2012-06-07',12,'AB'),
								(37,6,2,'Valoració de la documentació de la memoria i presentació de PFC j2ee','AT','2012-06-18',16,'AB');

									  
